<?php

namespace Ebuy\Deal\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Deal\Repositories\Eloquent\Filters\DealPublicFilter;
use Ebuy\Deal\Repositories\Eloquent\Presenters\DealListPresenter;
use Ebuy\Deal\Interfaces\DealRepositoryInterface;

class DealPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(DealRepositoryInterface $deal)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.deal.modules'), 'deal', guard_url('deal'));
        $this->repository = $deal;

    }

    /**
     * Show deal's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(DealPublicFilter::class)
            ->setPresenter(DealListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('deal::deal.names'))
            ->view('deal::public.deal.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show deal.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('deal::deal.name'))
            ->view('deal::public.deal.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
